<?php /*

**************************************************************************

Plugin Name:  Clean Archives Reloaded
Plugin URI:   http://www.viper007bond.com/wordpress-plugins/clean-archives-reloaded/
Description:  A slick, Javascript-enhanced post archive list generator. Based on concepts and ideas by <a href="http://www.kingcosmonaut.de/">Sebastian Schmieg</a>, <a href="http://www.sporadicnonsense.com/">Shawn Grimes</a>, and <a href="http://cdcstudios.com/">Chris O'Rourke</a>.
Version:      2.0.0
Author:       Viper007Bond
Author URI:   http://www.viper007bond.com/

**************************************************************************/

class CleanArchivesReloaded {

	########## SET OPTIONAL CONFIGURATION HERE ##########

	# Enable/disable the Javascript features (expand/collapse)
	var $usejs = TRUE; // default is TRUE

	# TRUE for listing posts within individual months from newest to oldest, FALSE for oldest to newest
	var $postnewtoold = FALSE; // default is FALSE

	# TRUE for listing months from newest to oldest, FALSE for oldest to newest
	var $monthnewtoold = TRUE;  // default is TRUE

	########## OKAY, STOP EDITING HERE ##########

	var $postcount = 0;
	var $postdata = array();
	var $html;

	// Class initialization
	function CleanArchivesReloaded() {
		if ( TRUE == $this->usejs ) add_action( 'wp_head', array(&$this, 'wp_head') );
		add_filter( 'the_content', array(&$this, 'PlaceholderReplace'), 8 );

		wp_enqueue_script( 'jquery' );

		// Load up the localization file if we're using WordPress in a different language
		// Place it in this plugin's folder and name it "car-[value in wp-config].mo"
		load_plugin_textdomain( 'car', '/wp-content/plugins/clean-archives-reloaded' );
	}


	// Output a little helper CSS and the Javascript for the plugin
	// Based on code from http://www.learningjquery.com/2007/03/accordion-madness
	function wp_head() { ?>

	<!-- Clean Archives Reloaded v2.0.0 -->
	<style type="text/css">.car-yearmonth { cursor: s-resize; } </style>
	<script type="text/javascript">
		//<![CDATA[
			var allexpanded = false;

			jQuery(document).ready(function() {
				jQuery('ul.car-monthlisting').hide();
				jQuery('ul.car-firstmonth').show();
				jQuery('span.car-yearmonth').click(function() {
					jQuery(this).next('ul').slideToggle('fast');
				});
				jQuery('.car-toggler').click(function() {
					if ( false == allexpanded ) {
						jQuery('ul.car-monthlisting').show();
						jQuery('.car-toggler').text('<?php echo js_escape( __('Collapse All', 'car') ); ?>');
						allexpanded = true;
					}
					else {
						jQuery('ul.car-monthlisting').hide();
						jQuery('.car-toggler').text('<?php echo js_escape( __('Expand All', 'car') ); ?>');
						allexpanded = false;
					}
					return false;
				});
			});
		//]]>
	</script>

<?php
	}


	// Grab all posts and filter them into an array
	function GenerateDataArray( $forceregen = FALSE ) {
		if ( !empty($this->postdata) && FALSE == $forceregen ) return;

		$posts = get_posts( 'numberposts=0' );

		$this->postcount = count( $posts );

		foreach( $posts as $post ) {
			$this->postdata[ mysql2date( 'Y.m', $post->post_date ) ][ mysql2date( 'U', $post->post_date ) ] = $post;
		}

		// Ensure the post sorting is correct
		foreach( $this->postdata as $key => $month ) {
			( TRUE != $this->postnewtoold ) ? ksort( $month ) : krsort( $month );
			$this->postdata[$key] = $month;
			unset($month);
		}
		( TRUE != $this->monthnewtoold ) ? ksort( $this->postdata ) : krsort( $this->postdata );
	}


	// Generates the HTML output from the data array
	function GenerateHTML( $forceregen = FALSE ) {
		global $wp_locale;

		if ( empty($this->postdata) || ( !empty($this->html) && FALSE == $forceregen ) ) return;

		$this->html = '';

		if ( TRUE == $this->usejs ) $this->html .= '<a href="#" class="car-toggler">' . __('Expand All', 'car') . "</a>\n\n";

		$this->html .= '<ul class="car-list">' . "\n";

		$firstmonth = TRUE;
		foreach( $this->postdata as $yearmonth => $posts ) {
			list( $year, $month ) = explode( '.', $yearmonth );

			$firstpost = TRUE;
			foreach( $posts as $post ) {
				if ( TRUE == $firstpost ) {
					$this->html .= '	<li><span class="car-yearmonth">' . sprintf( __('%1$s %2$d'), $wp_locale->get_month($month), $year ) . ' <span title="' . __('Post Count', 'car') . '">(' . count($posts) . ")</span></span>\n		<ul class='car-monthlisting";
					if ( TRUE == $firstmonth ) {
						$this->html .= ' car-firstmonth';
						$firstmonth = FALSE;
					}
					$this->html .= "'>\n";
					$firstpost = FALSE;
				}

				$this->html .= '			<li>' .  mysql2date( 'd', $post->post_date ) . ': <a href="' . get_permalink( $post->ID ) . '">' . get_the_title( $post->ID ) . '</a>';

				// Unless comments are closed and there are no comments, show the comment count
				if ( 0 != $post->comment_count || 'closed' != $post->comment_status ) $this->html .= ' <span title="' . __('Comment Count', 'car') . '">(' . $post->comment_count . ')</span>';

				$this->html .= "</li>\n";
			}

			$this->html .= "		</ul>\n	</li>\n";
		}

		$this->html .= "</ul>\n";
	}


	function PlaceholderReplace( $content ) {
		// Don't run if the placeholders aren't in this post
		if ( FALSE === stristr( $content, '[cleanarchivesreloaded]' ) && FALSE === stristr( $content, '[cartotalposts]' ) ) return $content;

		// Make sure we have data to use. These functions will automatically abort if they've already been run.
		$this->GenerateDataArray();
		$this->GenerateHTML();

		// Find and replace our placeholders
		$content = str_replace( '[cleanarchivesreloaded]', $this->html, $content );
		$content = str_replace( '[cartotalposts]', $this->postcount, $content );

		return $content;
	}
}

// Start this plugin once all other plugins are fully loaded
add_action( 'plugins_loaded', create_function( '', 'global $CleanArchivesReloaded; $CleanArchivesReloaded = new CleanArchivesReloaded();' ) );


// Some backwards compatibility wrapper functions
function car_total_posts() {
	global $CleanArchivesReloaded;
	$CleanArchivesReloaded->GenerateDataArray();
	$CleanArchivesReloaded->GenerateHTML();
	return $CleanArchivesReloaded->postcount;
}
function clean_archives_reloaded() {
	global $CleanArchivesReloaded;
	$CleanArchivesReloaded->GenerateDataArray();
	$CleanArchivesReloaded->GenerateHTML();
	echo $CleanArchivesReloaded->html;
}
function car_regenerate() {
	return FALSE;
}

?>